==> 4.7.4.tar.gz: terraform-provider-decort/wiki/4.5.3/06.01.42-Data_decort_disk_list_unattached.md <==
Функция доступна в провайдере версии 3.2 и выше.

_Data source_ функция **decort_disk_list_unattached** служит для получения информации о неподключенных к виртуальным машинам дисках.

## Аргументы
_Data source_ функция **decort_disk_list_unattached** принимает следующие аргументы:

| Аргумент | Тип | Обязательный | Описание |
| --- | --- | --- | --- | 
| by_id | int | :x: | Фильтр по ID диска |
| account_name | string | :x: | Фильтр по имени аккаунта |
| disk_max_size | int | :x: | Фильтр по макс. размеру диска |
| status | string | :x: | Фильтр по статусу |
| account_id | int | :x: | id аккаунта для получения списка дисков |
| type  | string | :x: | Тип диска. Возможные типы: "b" - boot_disk, "d" - data_disk |
| sep_id | int | :x: | Фильтр по SEP id. SEP это способ идентифицировать конкретную систему хранения, на ресурсах которой размещён данный диск |
| pool_name | string | :x: | Фильтр по наименованию pool |
| page | int | :x: | Номер страниц |
| size | int | :x: | Размер страницы |

## Возвращаемые значения
В случае успешного выполнения _data source_ функция **decort_disk_list_unattached** возвращает в указанную при вызове переменную, в поле _items_ массив, каждый элемент которого состоит из следующих параметров:

| Параметр | Тип | Описание |
| --- | --- | --- |
| _ckey | string | CKey |
| _meta | []string | Meta |
| account_id | int | id аккаунта |
| account_name | string | имя аккаунта | 
| acl | string | Acces Control List | 
| boot_partition | int | Загрузочный раздел |
| created_time | int | Время создания диска |
| deleted_time | int | Время удаления диска |
| desc | string | Описание диска |
| destruction_time | int | Время уничтожения диска |
| disk_path | string | Адрес диска |
| gid | int | Grid id |
| guid | int | Идентификатор диска |
| disk_id | int | id диска |
| image_id | int | id образа |
| images | []int | id образов |
| iotune | Struct{}[см. ниже](#описание-структуры-iotune) | Информация об ограничениях IO диска|
| iqn | string | iqn диска |
| login | string | Логин для доступа к диску |
| milestones | int | Вехи |
| disk_name | string | Наименование диска |
| order | int | Номер диска в последовательности |
| params | string | Параметры диска |
| parent_id | int | id родителя |
| passwd | string | Пароль для доступа к диску |
| pci_slot | int | id pci слота | 
| pool | string | Наименование пула диска |
| purge_time | int | Время удаления |
| reality_device_number | int | Реальный номер устройства |
| reference_id | int | id ссылки на диск |
| res_id | string | Идентификатор ресурса |
| res_name | string | Наименование ресурсов |
| role | string | Роль диска |
| sep_id | int | id sep |
| sep_type | string | Тип sep |
| shareable | bool | Флаг, говорящий о том, является ли диск общим |
| size_max | int | Максимальный размер диска |
| snapshots | []Struct{}[см. ниже](#описание-структуры-snapshots)| Снимки состояния диска|
| status | string | Статус диска |
| tech_status | string | Технический статус диска |
| type | string | Тип диска |
| vmid | int | id виртуальной машины (устаревшее)|

### Описание структуры iotune 
| Параметр | Тип | Описание |
| --- | --- | --- |
| read_bytes_sec | int | Кол-во байт для чтения в секунду |
| read_bytes_sec_max | int | Максимальное кол-во байт для чтения |
| read_iops_sec | int | Кол-во операций чтения io в секунду | |
| read_iops_sec_max | int | Максимальное число io операций чтения |
| size_iops_sec | int | Размер io операций |
| total_bytes_sec | int | Общий размер байт в секунду |
| total_bytes_sec_max | int | Максимальный общий размер байт в секунду |
| total_iops_sec | int | Общее кол-во io операций в секунду |
| total_iops_sec_max | int | Максимальное общее кол-во io операций в секунду |
| write_bytes_sec | int | Кол-во байт для записи в секунду |
| write_bytes_sec_max | int | Максимальное кол-во байт для записи в секунду |
| write_iops_sec | int | Кол-во операций записи в секунду |
| write_iops_sec_max | int | Максимальное число операций записей |

### Описание структуры snapshots 
| Параметр | Тип | Описание |
| --- | --- | --- |
| guid | string | id снимка |
| label | string | Наименование снимка |
| res_id | string | Ссылка на снимок |
| snap_set_guid | string | Установленный id снимка |
| snap_set_time | int | Установленное время снимка |
| timestamp | int | Время снимка |

## Пример использования
Пример вызова _data source_ функции **decort_disk_list_unattched**:
```terraform
data "decort_disk_list_unattached" "dlu" {
   #фильтр по id диска
  #опциональный параметр
  #тип - число
  #by_id = 100
 
  #фильтр по имени аккаунта
  #опциональный параметр
  #тип - строка
  #account_name = "user"

  #фильтр по максимальному размеру диска
  #опциональный параметр
  #тип - число
  #disk_max_size = 100

  #фильтр по статусу
  #опциональный параметр
  #тип - строка
  #status = "ENABLED"

  #фильтр по типу
  #опциональный параметр
  #тип - строка
  #возможные типы: "B" - boot_disk, "D" - data_disk
  #type = "D"

  #фильтр по id аккаунта
  #опциональный параметр
  #тип - число
  #account_id = 100

  #фильтр по id sep
  #опциональный параметр
  #тип - число
  #sep_id = 1

  #фильтр по имени pool
  #опциональный параметр
  #тип - строка
  #pool_name = "test"

  #номер страницы для отображения
  #опциональный параметр
  #тип - число
  #если не задан - выводятся все доступные данные
  #page = 2

  #размер страницы
  #опциональный параметр
  #тип - число
  #если не задан - выводятся все доступные данные
  #size = 3
}
# once the above directive completes, disk list will be accessible 
# as data.decort_disk_list_unattached.dlu.items
```

После успешного завершения такого вызова **decort_disk_list_unattached** в переменной `data.decort_disk_list_unattached.dlu` будут сохранены возвращаемые значения.

==> 4.9.0.tar.gz: terraform-provider-decort/wiki/4.8.2/06.01.42-Data_decort_disk_list_unattached.md <==
Функция доступна в провайдере версии 3.2 и выше.

_Data source_ функция **decort_disk_list_unattached** служит для получения информации о неподключенных к виртуальным машинам дисках.

## Аргументы
_Data source_ функция **decort_disk_list_unattached** принимает следующие аргументы:

| Аргумент | Тип | Обязательный | Описание |
| --- | --- | --- | --- | 
| by_id | int | :x: | Фильтр по ID диска |
| account_name | string | :x: | Фильтр по имени аккаунта |
| disk_max_size | int | :x: | Фильтр по макс. размеру диска |
| status | string | :x: | Фильтр по статусу |
| account_id | int | :x: | id аккаунта для получения списка дисков |
| type | string | :x: | Тип диска. Возможные типы: "b" - boot_disk, "d" - data_disk |
| sep_id | int | :x: | Фильтр по SEP id. SEP это способ идентифицировать конкретную систему хранения, на ресурсах которой размещён данный диск |
| pool_name | string | :x: | Фильтр по наименованию pool |
| sort_by | string | :x: | Фильтр по одному из поддерживаемых полей, формат: +или- название поля |
| page | int | :x: | Номер страниц |
| size | int | :x: | Размер страницы |

## Возвращаемые значения
В случае успешного выполнения _data source_ функция **decort_disk_list_unattached** возвращает в указанную при вызове переменную, в поле _items_ массив, каждый элемент которого состоит из следующих параметров:

| Параметр | Тип | Описание |
| --- | --- | --- |
| _ckey | string | CKey |
| _meta | []string | Meta |
| account_id | int | id аккаунта |
| account_name | string | имя аккаунта | 
| acl | string | Acces Control List | 
| boot_partition | int | Загрузочный раздел |
| created_time | int | Время создания диска |
| deleted_time | int | Время удаления диска |
| desc | string | Описание диска |
| destruction_time | int | Время уничтожения диска |
| disk_path | string | Адрес диска |
| gid | int | Grid id |
| guid | int | Идентификатор диска |
| disk_id | int | id диска |
| image_id | int | id образа |
| images | []int | id образов |
| iotune | Struct{}[см. ниже](#описание-структуры-iotune) | Информация об ограничениях IO диска |
| iqn | string | iqn диска |
| login | string | Логин для доступа к диску |
| milestones | int | Вехи |
| disk_name | string | Наименование диска |
| order | int | Номер диска в последовательности |
| params | string | Параметры диска |
| parent_id | int | id родителя |
| passwd | string | Пароль для доступа к диску |
| pci_slot | int | id pci слота | 
| pool | string | Наименование пула диска |
| purge_time | int | Время удаления |
| reality_device_number | int | Реальный номер устройства |
| reference_id | int | id ссылки на диск |
| res_id | string | Идентификатор ресурса |
| res_name | string | Наименование ресурсов |
| role | string | Роль диска |
| sep_id | int | id sep |
| sep_type | string | Тип sep |
| shareable | bool | Флаг, говорящий о том, является ли диск общим |
| size_max | int | Максимальный размер диска |
| snapshots | []Struct{}[см. ниже](#описание-структуры-snapshots) | Снимки состояния диска |
| status | string | Статус диска |
| tech_status | string | Технический статус диска |
| type | string | Тип диска |
| vmid | int | id виртуальной машины (устаревшее) |

### Описание структуры iotune 
| Параметр | Тип | Описание |
| --- | --- | --- |
| read_bytes_sec | int | Кол-во байт для чтения в секунду |
| read_bytes_sec_max | int | Максимальное кол-во байт для чтения |
| read_iops_sec | int | Кол-во операций чтения io в секунду |
| read_iops_sec_max | int | Максимальное число io операций чтения |
| size_iops_sec | int | Размер io операций |
| total_bytes_sec | int | Общий размер байт в секунду |
| total_bytes_sec_max | int | Максимальный общий размер байт в секунду |
| total_iops_sec | int | Общее кол-во io операций в секунду |
| total_iops_sec_max | int | Максимальное общее кол-во io операций в секунду |
| write_bytes_sec | int | Кол-во байт для записи в секунду |
| write_bytes_sec_max | int | Максимальное кол-во байт для записи в секунду |
| write_iops_sec | int | Кол-во операций записи в секунду |
| write_iops_sec_max | int | Максимальное число операций записей |

### Описание структуры snapshots 
| Параметр | Тип | Описание |
| --- | --- | --- |
| guid | string | id снимка |
| label | string | Наименование снимка |
| res_id | string | Ссылка на снимок |
| snap_set_guid | string | Установленный id снимка |
| snap_set_time | int | Установленное время снимка |
| timestamp | int | Время снимка |

## Пример использования
Пример вызова _data source_ функции **decort_disk_list_unattched**:
```terraform
data "decort_disk_list_unattached" "dlu" {
  #фильтр по id диска
  #опциональный параметр
  #тип - целое число
  #by_id = 100
 
  #фильтр по имени аккаунта
  #опциональный параметр
  #тип - строка
  #account_name = "user"

  #фильтр по максимальному размеру диска
  #опциональный параметр
  #тип - целое число
  #disk_max_size = 100

  #фильтр по статусу
  #опциональный параметр
  #тип - строка
  #status = "ENABLED"

  #фильтр по типу
  #опциональный параметр
  #тип - строка
  #возможные типы: "b" - boot_disk, "d" - data_disk
  #type = "d"

  #фильтр по id аккаунта
  #опциональный параметр
  #тип - целое число
  #account_id = 100

  #фильтр по id sep
  #опциональный параметр
  #тип - целое число
  #sep_id = 1

  #фильтр по имени pool
  #опциональный параметр
  #тип - строка
  #pool_name = "test"

  #сортировка по одному из поддерживаемых полей
  #опциональный параметр
  #тип - строка
  #формат - "+поле" по возрастанию / "-поле" по убыванию
  #sort_by = "+name"

  #номер страницы для отображения
  #опциональный параметр
  #тип - целое число
  #если не задан - выводятся все доступные данные
  #page = 2

  #размер страницы
  #опциональный параметр
  #тип - целое число
  #если не задан - выводятся все доступные данные
  #size = 3
}
```

После успешного завершения такого вызова **decort_disk_list_unattached** в переменной `data.decort_disk_list_unattached.dlu` будут сохранены возвращаемые значения.
